aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJeremy Lainé <jeremy.laine@m4x.org>2010-07-19 11:41:16 +0000
committerJeremy Lainé <jeremy.laine@m4x.org>2010-07-19 11:41:16 +0000
commit9d2d537c7bf395abe4e15528a50f7361205d26be (patch)
treeb48f62448a3cfbbba334624c1a343db5a6413fd5
parentc748d55bb608f194a52b09e0c99b781fc214f955 (diff)
downloadqxmpp-9d2d537c7bf395abe4e15528a50f7361205d26be.tar.gz
remove references to QXmppRoster::QXmppRosterEntry
-rw-r--r--source/QXmppRosterIq.cpp4
-rw-r--r--source/QXmppRosterManager.cpp13
-rw-r--r--source/QXmppRosterManager.h6
3 files changed, 10 insertions, 13 deletions
diff --git a/source/QXmppRosterIq.cpp b/source/QXmppRosterIq.cpp
index 204a4ada..baa38b47 100644
--- a/source/QXmppRosterIq.cpp
+++ b/source/QXmppRosterIq.cpp
@@ -155,8 +155,6 @@ void QXmppRosterIq::Item::setSubscriptionStatus(const QString& str)
/// Returns the subscription type of the roster entry.
///
-/// \return QXmppRosterEntry::SubscriptionType
-///
QXmppRosterIq::Item::SubscriptionType
QXmppRosterIq::Item::subscriptionType() const
@@ -166,7 +164,7 @@ QXmppRosterIq::Item::SubscriptionType
/// Sets the subscription type of the roster entry.
///
-/// \param type as a QXmppRosterEntry::SubscriptionType
+/// \param type
///
void QXmppRosterIq::Item::setSubscriptionType(SubscriptionType type)
diff --git a/source/QXmppRosterManager.h b/source/QXmppRosterManager.h
index 4cde5f98..28c8dc8b 100644
--- a/source/QXmppRosterManager.h
+++ b/source/QXmppRosterManager.h
@@ -73,7 +73,7 @@ public:
bool isRosterReceived();
QStringList getRosterBareJids() const;
- QXmppRosterManager::QXmppRosterEntry getRosterEntry(const QString& bareJid) const;
+ QXmppRosterIq::Item getRosterEntry(const QString& bareJid) const;
QStringList getResources(const QString& bareJid) const;
QMap<QString, QXmppPresence> getAllPresencesForBareJid(
@@ -83,7 +83,7 @@ public:
/// \cond
- QMap<QString, QXmppRosterManager::QXmppRosterEntry> Q_DECL_DEPRECATED getRosterEntries() const;
+ QMap<QString, QXmppRosterIq::Item> Q_DECL_DEPRECATED getRosterEntries() const;
QMap<QString, QMap<QString, QXmppPresence> > Q_DECL_DEPRECATED getAllPresences() const;
/// \endcond
@@ -102,7 +102,7 @@ private:
//reverse pointer to stream
QXmppStream* m_stream;
//map of bareJid and its rosterEntry
- QMap<QString, QXmppRosterManager::QXmppRosterEntry> m_entries;
+ QMap<QString, QXmppRosterIq::Item> m_entries;
// map of resources of the jid and map of resouces and presences
QMap<QString, QMap<QString, QXmppPresence> > m_presences;
// flag to store that the roster has been populated
diff --git a/source/QXmppRosterManager.cpp b/source/QXmppRosterManager.cpp
index 91882d8a..e2490372 100644
--- a/source/QXmppRosterManager.cpp
+++ b/source/QXmppRosterManager.cpp
@@ -69,7 +69,7 @@ void QXmppRosterManager::connected()
void QXmppRosterManager::disconnected()
{
- m_entries = QMap<QString, QXmppRosterManager::QXmppRosterEntry>();
+ m_entries = QMap<QString, QXmppRosterIq::Item>();
m_presences = QMap<QString, QMap<QString, QXmppPresence> >();
m_isRosterReceived = false;
}
@@ -167,31 +167,30 @@ QStringList QXmppRosterManager::getRosterBareJids() const
}
/// Returns the roster entry of the given bareJid. If the bareJid is not in the
/// database and empty QXmppRosterManager::QXmppRosterEntry will be returned.
///
/// \param bareJid as a QString
-/// \return QXmppRosterManager::QXmppRosterEntry
///
-QXmppRosterManager::QXmppRosterEntry QXmppRosterManager::getRosterEntry(
+QXmppRosterIq::Item QXmppRosterManager::getRosterEntry(
const QString& bareJid) const
{
// will return blank entry if bareJid does'nt exist
if(m_entries.contains(bareJid))
return m_entries.value(bareJid);
else
- return QXmppRosterManager::QXmppRosterEntry();
+ return QXmppRosterIq::Item();
}
/// [OBSOLETE] Returns all the roster entries in the database.
///
/// \return Map of bareJid and its respective QXmppRosterManager::QXmppRosterEntry
///
/// \note This function is obsolete, use getRosterBareJids() and
/// getRosterEntry() to get all the roster entries.
///
-QMap<QString, QXmppRosterManager::QXmppRosterEntry>
+QMap<QString, QXmppRosterIq::Item>
QXmppRosterManager::getRosterEntries() const
{
return m_entries;
@@ -167,31 +167,30 @@ QStringList QXmppRosterManager::getRosterBareJids() const
}
/// Returns the roster entry of the given bareJid. If the bareJid is not in the
-/// database and empty QXmppRosterManager::QXmppRosterEntry will be returned.
+/// database and empty QXmppRosterIq::Item will be returned.
///
/// \param bareJid as a QString
@@ -167,31 +167,30 @@ QStringList QXmppRosterManager::getRosterBareJids() const
/// [OBSOLETE] Returns all the roster entries in the database.
///
-/// \return Map of bareJid and its respective QXmppRosterManager::QXmppRosterEntry
+/// \return Map of bareJid and its respective QXmppRosterIq::Item
///
/// \note This function is obsolete, use getRosterBareJids() and